import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../bloc/user_list/bloc.dart';
import '../bloc/user_list/state.dart';
import '../bloc/user_list/event.dart';
import '../models/user.dart';

class UserSelectScreen extends StatefulWidget {
  final List<User> alreadyAdded;
  UserSelectScreen({Key key, this.alreadyAdded}) : super(key: key);

  @override
  _UserSelectScreenState createState() => _UserSelectScreenState();
}

class _UserSelectScreenState extends State<UserSelectScreen> {
  List<User> selected;

  @override
  void initState() {
    super.initState();
    selected = List<User>.from(widget.alreadyAdded ?? []);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    BlocProvider.of<UserListBloc>(context).add(UserListRefreshEvent());
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Select Users"),
      ),
      body: BlocBuilder<UserListBloc, UserListState>(
        builder: (context, state) {
          if (state is UserListLoadingState) {
            return Center(
              child: CircularProgressIndicator(),
            );
          }
          if (state is UserListLoadedState) {
            List<User> users = state.users;

            return Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: [
                Expanded(
                    child: ListView.builder(
                  itemBuilder: (context, index) {
                    User user = users[index];
                    return ListTile(
                      trailing: Checkbox(
                          value: selected.contains(user),
                          onChanged: (value) {
                            if (selected.contains(user)) {
                              selected.remove(user);
                            } else {
                              selected.add(user);
                            }
                            setState(() {});
                          }),
                      leading: CircleAvatar(
                        backgroundImage: NetworkImage("${user.profilePic}"),
                      ),
                      title: Text("${user.name}"),
                      subtitle: Text("${user.status ?? "Available"}"),
                    );
                  },
                  itemCount: users.length,
                  shrinkWrap: true,
                )),
                Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: CupertinoButton(
                    color: CupertinoColors.activeBlue,
                    onPressed: () {
                      Navigator.of(context).pop(selected);
                    },
                    child: Text("Continue (${selected.length})"),
                  ),
                )
              ],
            );
          }
          if (state is UserListErrorState) {
            return Center(
              child: Text("${state.error}"),
            );
          }
          return Center(
            child: Text("Not Exists"),
          );
        },
      ),
    );
  }
}
