import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import '../models/user.dart';
import '../screens/user_select_screen.dart';

class UserSelectWidget extends StatefulWidget {
  final void Function(List<User> users) onChanged;
  UserSelectWidget({Key key, @required this.onChanged}) : super(key: key);

  @override
  _UserSelectWidgetState createState() => _UserSelectWidgetState();
}

class _UserSelectWidgetState extends State<UserSelectWidget> {
  List<User> usersSelected;

  @override
  void initState() {
    super.initState();
    usersSelected = [];
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        buildAddOption(),
        GridView.builder(
            gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
              crossAxisCount: MediaQuery.of(context).size.width ~/ 100,
              crossAxisSpacing: 1,
              childAspectRatio: 1,
            ),
            itemCount: usersSelected.length,
            shrinkWrap: true,
            physics: ClampingScrollPhysics(),
            itemBuilder: (context, index) => buildUser(usersSelected[index]))
      ],
    );
  }

  Widget buildUser(User user) {
    return Center(
      child: Stack(
        alignment: Alignment.topRight,
        children: [
          Container(
            constraints: BoxConstraints(maxHeight: 100, maxWidth: 100),
            decoration: BoxDecoration(
                shape: BoxShape.circle,
                color: Colors.white,
                boxShadow: [
                  BoxShadow(
                      color: Colors.black12,
                      blurRadius: 12,
                      offset: Offset(0, 1))
                ]),
            padding: EdgeInsets.all(4),
            child: CircleAvatar(
              backgroundImage: NetworkImage("${user.profilePic}"),
              maxRadius: 26,
            ),
          ),
          GestureDetector(
            onTap: () {
              removeUser(user);
            },
            child: Icon(
              Icons.cancel,
              color: Colors.black,
            ),
          )
        ],
      ),
    );
  }

  Widget buildAddOption() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: <Widget>[
        Expanded(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Text(
                "People",
                style: TextStyle(
                    fontSize: 18,
                    fontWeight: FontWeight.w600,
                    color: Colors.black),
              ),
              Text("Invite your friends to meeting")
            ],
          ),
        ),
        CupertinoButton(
          child: Icon(
            Icons.add_circle_outline,
            color: Colors.black54,
          ),
          minSize: 0,
          padding: EdgeInsets.all(0),
          onPressed: pickUsers,
        )
      ],
    );
  }

  Future<void> pickUsers() async {
    List<User> contacts = (await Navigator.of(context).push(MaterialPageRoute(
        builder: (context) => UserSelectScreen(
              alreadyAdded: usersSelected,
            ))));
    usersSelected = (contacts ?? usersSelected);
    if (mounted) {
      setState(() {});
    }
    widget.onChanged(usersSelected);
  }

  void removeUser(User user) {
    setState(() {
      usersSelected.remove(user);
    });
    widget.onChanged(usersSelected);
  }
}
